==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/apigateway/Model.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * RestApi api;
 * // We define the JSON Schema for the transformed valid response
 * Model responseModel = api.addModel("ResponseModel", ModelOptions.builder()
 *         .contentType("application/json")
 *         .modelName("ResponseModel")
 *         .schema(JsonSchema.builder()
 *                 .schema(JsonSchemaVersion.DRAFT4)
 *                 .title("pollResponse")
 *                 .type(JsonSchemaType.OBJECT)
 *                 .properties(Map.of(
 *                         "state", JsonSchema.builder().type(JsonSchemaType.STRING).build(),
 *                         "greeting", JsonSchema.builder().type(JsonSchemaType.STRING).build()))
 *                 .build())
 *         .build());
 * // We define the JSON Schema for the transformed error response
 * Model errorResponseModel = api.addModel("ErrorResponseModel", ModelOptions.builder()
 *         .contentType("application/json")
 *         .modelName("ErrorResponseModel")
 *         .schema(JsonSchema.builder()
 *                 .schema(JsonSchemaVersion.DRAFT4)
 *                 .title("errorResponse")
 *                 .type(JsonSchemaType.OBJECT)
 *                 .properties(Map.of(
 *                         "state", JsonSchema.builder().type(JsonSchemaType.STRING).build(),
 *                         "message", JsonSchema.builder().type(JsonSchemaType.STRING).build()))
 *                 .build())
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:08.589Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_apigateway.Model")
public class Model extends software.amazon.awscdk.Resource implements software.amazon.awscdk.services.apigateway.IModel {

    protected Model(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Model(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        EMPTY_MODEL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.apigateway.Model.class, "EMPTY_MODEL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IModel.class));
        ERROR_MODEL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.apigateway.Model.class, "ERROR_MODEL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IModel.class));
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Model(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.ModelProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param modelName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.IModel fromModelName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String modelName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.apigateway.Model.class, "fromModelName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IModel.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(modelName, "modelName is required") });
    }

    /**
     * Represents a reference to a REST API's Empty model, which is available as part of the model collection by default.
     * <p>
     * This can be used for mapping
     * JSON responses from an integration to what is returned to a client,
     * where strong typing is not required. In the absence of any defined
     * model, the Empty model will be used to return the response payload
     * unmapped.
     * <p>
     * Definition
     * {
     * "$schema" : "http://json-schema.org/draft-04/schema#",
     * "title" : "Empty Schema",
     * "type" : "object"
     * }
     * <p>
     * @see <a href="https://docs.amazonaws.cn/en_us/apigateway/latest/developerguide/models-mappings.html#models-mappings-models">https://docs.amazonaws.cn/en_us/apigateway/latest/developerguide/models-mappings.html#models-mappings-models</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.apigateway.IModel EMPTY_MODEL;

    /**
     * Represents a reference to a REST API's Error model, which is available as part of the model collection by default.
     * <p>
     * This can be used for mapping
     * error JSON responses from an integration to a client, where a simple
     * generic message field is sufficient to map and return an error payload.
     * <p>
     * Definition
     * {
     * "$schema" : "http://json-schema.org/draft-04/schema#",
     * "title" : "Error Schema",
     * "type" : "object",
     * "properties" : {
     * "message" : { "type" : "string" }
     * }
     * }
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.apigateway.IModel ERROR_MODEL;

    /**
     * Returns the model name, such as 'myModel'.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getModelId() {
        return software.amazon.jsii.Kernel.get(this, "modelId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.apigateway.Model}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.apigateway.Model> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.apigateway.ModelProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.apigateway.ModelProps.Builder();
        }

        /**
         * The schema to use to transform data to one or more output formats.
         * <p>
         * Specify null ({}) if you don't want to specify a schema.
         * <p>
         * @return {@code this}
         * @param schema The schema to use to transform data to one or more output formats. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schema(final software.amazon.awscdk.services.apigateway.JsonSchema schema) {
            this.props.schema(schema);
            return this;
        }

        /**
         * The content type for the model.
         * <p>
         * You can also force a
         * content type in the request or response model mapping.
         * <p>
         * Default: 'application/json'
         * <p>
         * @return {@code this}
         * @param contentType The content type for the model. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder contentType(final java.lang.String contentType) {
            this.props.contentType(contentType);
            return this;
        }

        /**
         * A description that identifies this model.
         * <p>
         * Default: None
         * <p>
         * @return {@code this}
         * @param description A description that identifies this model. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * A name for the model.
         * <p>
         * Important
         * If you specify a name, you cannot perform updates that
         * require replacement of this resource. You can perform
         * updates that require no or some interruption. If you
         * must replace the resource, specify a new name.
         * <p>
         * Default: <auto> If you don't specify a name,
         * AWS CloudFormation generates a unique physical ID and
         * uses that ID for the model name. For more information,
         * see Name Type.
         * <p>
         * @return {@code this}
         * @param modelName A name for the model. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder modelName(final java.lang.String modelName) {
            this.props.modelName(modelName);
            return this;
        }

        /**
         * The rest API that this model is part of.
         * <p>
         * The reason we need the RestApi object itself and not just the ID is because the model
         * is being tracked by the top-level RestApi object for the purpose of calculating it's
         * hash to determine the ID of the deployment. This allows us to automatically update
         * the deployment when the model of the REST API changes.
         * <p>
         * @return {@code this}
         * @param restApi The rest API that this model is part of. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder restApi(final software.amazon.awscdk.services.apigateway.IRestApi restApi) {
            this.props.restApi(restApi);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.apigateway.Model}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.apigateway.Model build() {
            return new software.amazon.awscdk.services.apigateway.Model(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/apigateway/Model.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * RestApi api;
 * // We define the JSON Schema for the transformed valid response
 * Model responseModel = api.addModel("ResponseModel", ModelOptions.builder()
 *         .contentType("application/json")
 *         .modelName("ResponseModel")
 *         .schema(JsonSchema.builder()
 *                 .schema(JsonSchemaVersion.DRAFT4)
 *                 .title("pollResponse")
 *                 .type(JsonSchemaType.OBJECT)
 *                 .properties(Map.of(
 *                         "state", JsonSchema.builder().type(JsonSchemaType.STRING).build(),
 *                         "greeting", JsonSchema.builder().type(JsonSchemaType.STRING).build()))
 *                 .build())
 *         .build());
 * // We define the JSON Schema for the transformed error response
 * Model errorResponseModel = api.addModel("ErrorResponseModel", ModelOptions.builder()
 *         .contentType("application/json")
 *         .modelName("ErrorResponseModel")
 *         .schema(JsonSchema.builder()
 *                 .schema(JsonSchemaVersion.DRAFT4)
 *                 .title("errorResponse")
 *                 .type(JsonSchemaType.OBJECT)
 *                 .properties(Map.of(
 *                         "state", JsonSchema.builder().type(JsonSchemaType.STRING).build(),
 *                         "message", JsonSchema.builder().type(JsonSchemaType.STRING).build()))
 *                 .build())
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:27.540Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_apigateway.Model")
public class Model extends software.amazon.awscdk.Resource implements software.amazon.awscdk.services.apigateway.IModel {

    protected Model(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Model(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        EMPTY_MODEL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.apigateway.Model.class, "EMPTY_MODEL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IModel.class));
        ERROR_MODEL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.apigateway.Model.class, "ERROR_MODEL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IModel.class));
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Model(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.ModelProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param modelName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.IModel fromModelName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String modelName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.apigateway.Model.class, "fromModelName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IModel.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(modelName, "modelName is required") });
    }

    /**
     * Represents a reference to a REST API's Empty model, which is available as part of the model collection by default.
     * <p>
     * This can be used for mapping
     * JSON responses from an integration to what is returned to a client,
     * where strong typing is not required. In the absence of any defined
     * model, the Empty model will be used to return the response payload
     * unmapped.
     * <p>
     * Definition
     * {
     * "$schema" : "http://json-schema.org/draft-04/schema#",
     * "title" : "Empty Schema",
     * "type" : "object"
     * }
     * <p>
     * @see <a href="https://docs.amazonaws.cn/en_us/apigateway/latest/developerguide/models-mappings.html#models-mappings-models">https://docs.amazonaws.cn/en_us/apigateway/latest/developerguide/models-mappings.html#models-mappings-models</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.apigateway.IModel EMPTY_MODEL;

    /**
     * Represents a reference to a REST API's Error model, which is available as part of the model collection by default.
     * <p>
     * This can be used for mapping
     * error JSON responses from an integration to a client, where a simple
     * generic message field is sufficient to map and return an error payload.
     * <p>
     * Definition
     * {
     * "$schema" : "http://json-schema.org/draft-04/schema#",
     * "title" : "Error Schema",
     * "type" : "object",
     * "properties" : {
     * "message" : { "type" : "string" }
     * }
     * }
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.apigateway.IModel ERROR_MODEL;

    /**
     * Returns the model name, such as 'myModel'.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getModelId() {
        return software.amazon.jsii.Kernel.get(this, "modelId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.apigateway.Model}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.apigateway.Model> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.apigateway.ModelProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.apigateway.ModelProps.Builder();
        }

        /**
         * The schema to use to transform data to one or more output formats.
         * <p>
         * Specify null ({}) if you don't want to specify a schema.
         * <p>
         * @return {@code this}
         * @param schema The schema to use to transform data to one or more output formats. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schema(final software.amazon.awscdk.services.apigateway.JsonSchema schema) {
            this.props.schema(schema);
            return this;
        }

        /**
         * The content type for the model.
         * <p>
         * You can also force a
         * content type in the request or response model mapping.
         * <p>
         * Default: 'application/json'
         * <p>
         * @return {@code this}
         * @param contentType The content type for the model. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder contentType(final java.lang.String contentType) {
            this.props.contentType(contentType);
            return this;
        }

        /**
         * A description that identifies this model.
         * <p>
         * Default: None
         * <p>
         * @return {@code this}
         * @param description A description that identifies this model. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * A name for the model.
         * <p>
         * Important
         * If you specify a name, you cannot perform updates that
         * require replacement of this resource. You can perform
         * updates that require no or some interruption. If you
         * must replace the resource, specify a new name.
         * <p>
         * Default: <auto> If you don't specify a name,
         * AWS CloudFormation generates a unique physical ID and
         * uses that ID for the model name. For more information,
         * see Name Type.
         * <p>
         * @return {@code this}
         * @param modelName A name for the model. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder modelName(final java.lang.String modelName) {
            this.props.modelName(modelName);
            return this;
        }

        /**
         * The rest API that this model is part of.
         * <p>
         * The reason we need the RestApi object itself and not just the ID is because the model
         * is being tracked by the top-level RestApi object for the purpose of calculating it's
         * hash to determine the ID of the deployment. This allows us to automatically update
         * the deployment when the model of the REST API changes.
         * <p>
         * @return {@code this}
         * @param restApi The rest API that this model is part of. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder restApi(final software.amazon.awscdk.services.apigateway.IRestApi restApi) {
            this.props.restApi(restApi);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.apigateway.Model}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.apigateway.Model build() {
            return new software.amazon.awscdk.services.apigateway.Model(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
